import React from 'react';
import { css } from '@emotion/react';
import { useTheme } from '@mui/material/styles';

type SeparatorProps = {
  responsive: boolean;
  text: string;
  maxWidth?: number;
};

const Separator: React.FunctionComponent<SeparatorProps> = ({
  responsive,
  text,
  maxWidth = undefined,
}: SeparatorProps) => {
  const theme = useTheme();

  const containerStyle = css([
    {
      position: 'relative',
      width: '100%',
      height: '90%',
      top: '5%',
      display: 'inline-block',
    },
    responsive && {
      [theme.breakpoints.down('md')]: {
        paddingTop: '25px',
        paddingBottom: '25px',
      },
    },
    !responsive && {
      paddingTop: '25px',
      paddingBottom: '25px',
    },
    maxWidth && {
      maxWidth: maxWidth,
    },
  ]);

  const lineStyle = css([
    {
      backgroundColor: '#dce2e6',
      position: 'absolute',
      left: '50%',
      height: '1px',
      width: '100%',
      transform: 'translateX(-50%)',
    },
    responsive && {
      [theme.breakpoints.up('md')]: {
        height: '100%',
        width: '1px',
        transform: 'translateX(0%) translateY(0%)',
      },
    },
  ]);

  const textStyle = css([
    {
      backgroundColor: '#DCE2E6',
      padding: '5px 10px',
      minWidth: '36px',
      borderRadius: '18px',
      fontSize: '18px',
      color: 'white',
      textAlign: 'center',
      display: 'inline-block',
      position: 'absolute',
      transform: 'translateX(-50%) translateY(-50%)',
      left: '50%',
    },
    responsive && {
      [theme.breakpoints.up('md')]: {
        top: '15%',
      },
    },
  ]);

  return (
    <div css={containerStyle}>
      <div css={lineStyle}></div>
      <div css={textStyle}>{text}</div>
    </div>
  );
};

export default Separator;
